@@ -5,13 +5,12 @@
 
 
 dtou *.*
-dtou ickspec
 dtou etc/intercal.el
 dtou src/*.c
 dtou src/*.h
 dtou src/*.l
 dtou src/*.y
-dtou src/*.in
+dtou src/*.sh
 dtou pit/*.doc
 dtou pit/*.i
 dtou pit/tests/*.doc
@@ -19,4 +18,3 @@ dtou pit/tests/*.i
 dtou pit/lib/*.doc
 dtou pit/lib/*.i
 utod *.bat
-utod configdj.sh
\ No newline at end of file
