@@ -3,34 +3,28 @@
    This file is GPL'd, and so can be freely redistributed but has
    absolutely no warranty. */
 
+#include <time.h>
 #define YUK(t,u) yukline(t,u)
 #define YUKTERM yukterm()
 
 #define YUKEND 5
 
-/*@-exportlocal@*/ /* because these are used by generated programs */
 extern void yukline(int,int);
 extern void yukterm(void);
 
-extern int ick_abstained[];
+extern int abstained[];
 extern int yukopts;
-extern int ick_lineno;
+extern int lineno;
 extern int yuklines;
 extern int yukcommands;
-/*@-incondefs@*/ /* because it's a different textlines to the one in ick.h */
 extern char *textlines[];
-/*@=incondefs@*/
 extern int lineofaboff[];
 extern char *yukexplain[];
 
 extern int yukloop;
-/*@=exportlocal@*/
 
-/* Defines that change the functions used for profiling. */
-
-/* Define the following to the timing function you want for profiling, or leave
-   it undef to use the value computed by config.sh. */
-#undef YPTIMERTYPE
+/* Defines that change the functions used for profiling */
+#define YPTIMERTYPE 2
 /* 0 to use clock(), 1 to use gettimeofday() and long,
    2 to use gettimeofday() and long long, 3 to use gethrtime()
    4 to use times() */
@@ -46,23 +40,6 @@ extern int yukloop;
          you get will be basically meaningless as the base information can't
          be accurately obtained (the resolution is slightly worse than 50ms, 
          which is far too slow for profiling). */
-#ifndef YPTIMERTIME
-# ifdef HAVE_GETHRTIME
-#  define YPTIMERTYPE 3
-# else
-#  ifdef HAVE_GETTIMEOFDAY
-/* Allow for an erroneous blank value for SIZEOF_LONG_LONG_INT. */
-#   if SIZEOF_LONG_LONG_INT + 0 > 0
-#    define YPTIMERTYPE 2
-#   else
-#    define YPTIMERTYPE 1
-#   endif
-#  else
-#   define YPTIMERTYPE 0
-#  endif
-# endif
-#endif
-
 
 #if YPTIMERTYPE == 0
 #define YPTIMERTFORMAT "lu"
@@ -126,8 +103,3 @@ typedef struct yukvar_tag
 } yukvar;
 
 extern yukvar yukvars[];
-
-/*@-exportlocal@*/ /* this needs to be global */
-extern char** globalargv;
-extern int globalargc;
-/*@=exportlocal@*/
